pub fn current_time() -> u64Expand description
Get the current time in microseconds
This function returns the current system time in microseconds since boot. For filesystem operations, this provides a monotonic timestamp.
pub fn current_time() -> u64Get the current time in microseconds
This function returns the current system time in microseconds since boot. For filesystem operations, this provides a monotonic timestamp.