pub fn current_time_ns() -> u64Expand description
Get the current time in nanoseconds
This function returns the current system time in nanoseconds since boot. Useful for high-resolution timestamps in input events and profiling.
pub fn current_time_ns() -> u64Get the current time in nanoseconds
This function returns the current system time in nanoseconds since boot. Useful for high-resolution timestamps in input events and profiling.